%global min_libdnf_version 0.66.0

Summary:        Package manager based on libdnf and libsolv. Replaces YUM.
Name:           dnf
Version:        4.16.2
Release:        3%{?dist}
License:        GPLv2+
URL:            https://github.com/rpm-software-management/dnf
Source0:        https://github.com/rpm-software-management/dnf/archive/%{version}/%{version}.tar.gz
Source1:        dnf-automatic.8
Source2:        dnf-transaction-json.5
Source3:        dnf.8
Source4:        dnf.conf.5
Source5:        dnf.modularity.7
Source6:        yum-aliases.1
Source7:        yum-shell.8
Source8:        yum.8
Source9:        yum.conf.5
Source10:       yum2dnf.8
Patch5000:      5000-default-zchunk-false.patch
Patch0001:      0001-Fix-bash-completion-due-to-sqlite-changes.patch
BuildRequires:  cmake gettext systemd bash-completion
Requires:       python3-%{name} = %{version}-%{release}
Recommends:     (python3-dbus if NetworkManager) (sqlite if bash-completion)
Provides:       dnf-command(alias)
Provides:       dnf-command(autoremove)
Provides:       dnf-command(check-update)
Provides:       dnf-command(clean)
Provides:       dnf-command(distro-sync)
Provides:       dnf-command(downgrade)
Provides:       dnf-command(group)
Provides:       dnf-command(history)
Provides:       dnf-command(info)
Provides:       dnf-command(install)
Provides:       dnf-command(list)
Provides:       dnf-command(makecache)
Provides:       dnf-command(mark)
Provides:       dnf-command(provides)
Provides:       dnf-command(reinstall)
Provides:       dnf-command(remove)
Provides:       dnf-command(repolist)
Provides:       dnf-command(repoquery)
Provides:       dnf-command(repository-packages)
Provides:       dnf-command(search)
Provides:       dnf-command(updateinfo)
Provides:       dnf-command(upgrade)
Provides:       dnf-command(upgrade-to)
BuildArch:      noarch

%description
Dandified YUM (DNF) is the next upcoming major version of YUM. It does package 
management using RPM, libsolv and hawkey libraries. For metadata handling and 
package downloads it utilizes librepo. To process and effectively handle the 
comps data it uses libcomps.

%package data
Summary:        Common data and configuration files for DNF
Provides:       %{name}-conf = %{version}-%{release}

%description data
Common data and configuration files for DNF

%package -n yum
Summary:        Package manager
Requires:       %{name} = %{version}-%{release}
Provides:       %{name}-yum = %{version}-%{release}

%description -n yum
Utility that allows users to manage packages on their systems. \
It supports RPMs, modules and comps groups & environments.

%package -n python3-%{name}
Summary:        Python 3 interface to DNF
BuildRequires:  python3-devel python3-hawkey >= %{min_libdnf_version} python3-libdnf >= %{min_libdnf_version} python3-libcomps python3-libdnf
BuildRequires:  libmodulemd python3-gpg python3-rpm
Requires:       %{name}-data = %{version}-%{release} python3-hawkey >= %{min_libdnf_version} python3-libdnf >= %{min_libdnf_version}
Requires:       libmodulemd python3-gpg python3-libcomps python3-libdnf python3-rpm
Provides:       python%{python3_version}-%{name} = %{version}-%{release}
Provides:       python-%{name} = %{version}-%{release}
Recommends:     python3-unbound rpm-plugin-systemd-inhibit

%description -n python3-%{name}
Python 3 interface to DNF.

%package automatic
Summary:        Package manager - automated upgrades
BuildRequires:  systemd
Requires:       %{name} = %{version}-%{release}
Requires(post): systemd 
Requires(preun): systemd 
Requires(postun): systemd

%description automatic
Systemd units that can periodically download package upgrades and apply them.

%prep
%autosetup -p1
mkdir build

%build
pushd build
  %cmake .. -DPYTHON_DESIRED:FILEPATH=%{__python3} -DDNF_VERSION=%{version} -DWITH_MAN=0
  pushd %{_vpath_builddir}
    %make_build
  popd
popd

%install
pushd build/%{_vpath_builddir}
  %make_install
popd

%find_lang %{name}
mkdir -p %{buildroot}%{_sysconfdir}/%{name}
pushd %{buildroot}%{_sysconfdir}/%{name}
  for folder in vars aliases.d plugins modules.d modules.defaults.d
  do
    mkdir -p $folder
  done
popd
mkdir -p %{buildroot}%{python3_sitelib}/%{name}-plugins/__pycache__/
mkdir -p %{buildroot}%{_localstatedir}/log/
mkdir -p %{buildroot}%{_var}/cache/dnf/
touch %{buildroot}%{_localstatedir}/log/%{name}.log
mv %{buildroot}%{_bindir}/dnf-automatic-3 %{buildroot}%{_bindir}/dnf-automatic
ln -sr %{buildroot}%{_bindir}/dnf-3 %{buildroot}%{_bindir}/dnf
ln -sr  %{buildroot}%{_bindir}/dnf-3 %{buildroot}%{_bindir}/yum
rm -vf %{buildroot}%{_bindir}/dnf-automatic-*
mv -f %{buildroot}%{_sysconfdir}/%{name}/%{name}-strict.conf %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf
ln -sr  %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf %{buildroot}%{_sysconfdir}/yum.conf
mkdir -p %{buildroot}%{_sysconfdir}/yum
ln -sr  %{buildroot}%{_sysconfdir}/%{name}/plugins %{buildroot}%{_sysconfdir}/yum/pluginconf.d
ln -sr  %{buildroot}%{_sysconfdir}/%{name}/protected.d %{buildroot}%{_sysconfdir}/yum/protected.d
ln -sr  %{buildroot}%{_sysconfdir}/%{name}/vars %{buildroot}%{_sysconfdir}/yum/vars

mkdir -p %{buildroot}%{_mandir}/man1
mkdir -p %{buildroot}%{_mandir}/man5
mkdir -p %{buildroot}%{_mandir}/man7
mkdir -p %{buildroot}%{_mandir}/man8

gzip -c %{SOURCE1} > %{buildroot}%{_mandir}/man8/dnf-automatic.8.gz
gzip -c %{SOURCE2} > %{buildroot}%{_mandir}/man5/dnf-transaction-json.5.gz
gzip -c %{SOURCE3} > %{buildroot}%{_mandir}/man8/dnf.8.gz
gzip -c %{SOURCE4} > %{buildroot}%{_mandir}/man5/dnf.conf.5.gz
gzip -c %{SOURCE5} > %{buildroot}%{_mandir}/man7/dnf.modularity.7.gz
gzip -c %{SOURCE6} > %{buildroot}%{_mandir}/man1/yum-aliases.1.gz
gzip -c %{SOURCE7} > %{buildroot}%{_mandir}/man8/yum-shell.8.gz
gzip -c %{SOURCE8} > %{buildroot}%{_mandir}/man8/yum.8.gz
gzip -c %{SOURCE9} > %{buildroot}%{_mandir}/man5/yum.conf.5.gz
gzip -c %{SOURCE10} > %{buildroot}%{_mandir}/man8/yum2dnf.8.gz

%check
pushd build/%{_vpath_builddir}
  ctest -VV
popd

%post
%systemd_post dnf-makecache.timer

%preun
%systemd_preun dnf-makecache.timer

%postun
%systemd_postun_with_restart dnf-makecache.timer

%post automatic
%systemd_post dnf-automatic.timer dnf-automatic-notifyonly.timer dnf-automatic-download.timer dnf-automatic-install.timer

%preun automatic
%systemd_preun dnf-automatic.timer dnf-automatic-notifyonly.timer dnf-automatic-download.timer dnf-automatic-install.timer

%postun automatic
%systemd_postun_with_restart dnf-automatic.timer dnf-automatic-notifyonly.timer dnf-automatic-download.timer dnf-automatic-install.timer

%files -f %{name}.lang
%{_bindir}/%{name}
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/%{name}
%{_mandir}/man8/%{name}.8*
%{_mandir}/man8/yum2dnf.8*
%{_mandir}/man7/dnf.modularity.7*
%{_mandir}/man5/dnf-transaction-json.5*
%{_unitdir}/%{name}-makecache.service
%{_unitdir}/%{name}-makecache.timer
%{_var}/cache/%{name}/

%files data
%license COPYING PACKAGE-LICENSING
%doc AUTHORS README.rst
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/modules.d
%dir %{_sysconfdir}/%{name}/modules.defaults.d
%dir %{_sysconfdir}/%{name}/plugins
%dir %{_sysconfdir}/%{name}/protected.d
%dir %{_sysconfdir}/%{name}/vars
%dir %{_sysconfdir}/%{name}/aliases.d
%exclude %{_sysconfdir}/%{name}/aliases.d/zypper.conf
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%config(noreplace) %{_sysconfdir}/%{name}/protected.d/python3-%{name}.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config %{_sysconfdir}/%{name}/protected.d/%{name}.conf
%ghost %attr(644,-,-) %{_localstatedir}/log/hawkey.log
%ghost %attr(644,-,-) %{_localstatedir}/log/%{name}.log
%ghost %attr(644,-,-) %{_localstatedir}/log/%{name}.librepo.log
%ghost %attr(644,-,-) %{_localstatedir}/log/%{name}.rpm.log
%ghost %attr(644,-,-) %{_localstatedir}/log/%{name}.plugin.log
%ghost %attr(755,-,-) %dir %{_sharedstatedir}/%{name}
%ghost %attr(644,-,-) %{_sharedstatedir}/%{name}/groups.json
%ghost %attr(755,-,-) %dir %{_sharedstatedir}/%{name}/yumdb
%ghost %attr(755,-,-) %dir %{_sharedstatedir}/%{name}/history
%{_mandir}/man5/%{name}.conf.5*
%{_tmpfilesdir}/%{name}.conf
%exclude %{_sysconfdir}/libreport/events.d/collect_dnf.conf

%files -n yum
%{_bindir}/yum
%{_sysconfdir}/yum.conf
%{_sysconfdir}/yum/pluginconf.d
%{_sysconfdir}/yum/protected.d
%{_sysconfdir}/yum/vars
%{_mandir}/man8/yum.8*
%{_mandir}/man5/yum.conf.5.*
%{_mandir}/man8/yum-shell.8*
%{_mandir}/man1/yum-aliases.1*
%config %{_sysconfdir}/%{name}/protected.d/yum.conf

%files -n python3-%{name}
%{_bindir}/%{name}-3
%exclude %{python3_sitelib}/%{name}/automatic
%{python3_sitelib}/%{name}/
%dir %{python3_sitelib}/%{name}-plugins
%dir %{python3_sitelib}/%{name}-plugins/__pycache__

%files automatic
%{_bindir}/%{name}-automatic
%config(noreplace) %{_sysconfdir}/%{name}/automatic.conf
%{_mandir}/man8/%{name}-automatic.8*
%{_unitdir}/%{name}-automatic.service
%{_unitdir}/%{name}-automatic.timer
%{_unitdir}/%{name}-automatic-notifyonly.service
%{_unitdir}/%{name}-automatic-notifyonly.timer
%{_unitdir}/%{name}-automatic-download.service
%{_unitdir}/%{name}-automatic-download.timer
%{_unitdir}/%{name}-automatic-install.service
%{_unitdir}/%{name}-automatic-install.timer
%{python3_sitelib}/%{name}/automatic/

%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.16.2-3
- Rebuilt for loongarch release

* Wed Jan 17 2024 Ze Zhang <bbrucezhang@tencent.com> - 4.16.2-2
- Fix bash completion due to sqlite changes

* Wed Jan 17 2024 Ze Zhang <bbrucezhang@tencent.com> - 4.16.2-1
- Update to 4.16.2

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.15.1-4
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.15.1-3
- Rebuilt for OpenCloudOS Stream 23.09

* Wed Aug 23 2023 cunshunxia <cunshunxia@tencent.com> - 4.15.1-2
- Rebuilt for libdnf 0.70.2

* Tue Aug 15 2023 Xiaojie Chen <jackxjchen@tencent.com> - 4.15.1-1
- Upgrade to upstream version 4.15.1

* Tue Jul 11 2023 Yi Lin <nilusyi@tencent.com> - 4.14.0-1
- upgrade to 4.14

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.12.0-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.12.0-2
- Rebuilt for OpenCloudOS Stream 23

* Fri Apr 29 2022 Xun Zhong <victorzhong@tencent.com> - 4.12.0-1
- Initial build
